robotframework-openafslibrary
=============================

**robotframework-openafslibrary** is a Robot Framework test library for OpenAFS.

Installation
============

Install with `pip`::

    pip install robotframework-openafslibrary

Install from source code::

    python configure.py
    make install

